(function() {

if (!self.eAu) { self.eAu = {}; }
if (eAu.Timer) { return; }

eAu.Timer = Class.create({
	initialize: function(duration, options) {
		if (!Object.isNumber(duration) || duration <= 0) {
			return;
		}
		this._options = Object.extend({
			start:     Prototype.K, /* Исполняется при старте таймера */
			finish:    Prototype.K, /* Исполняется по завершении таймера */
			callback:  Prototype.K, /* Исполняется в фиксированные промежутки времени */
			interrupt: Prototype.K, /* Исполняется при прерывании таймера */
			onError: Prototype.K,
			precision: 250, /* Как часто будет исполняться callback */
			delay: 0 /* Пока не работает */
		}, options || {});
		var date = (new Date());
		this._startTime = this._currentTime = date.getTime();
		this._timezone = date.getTimezoneOffset();
		this._duration = this._options.duration = duration;
		this._iteration = 0;
		this._start();
	},
	_start: function() {
		var self = this;
		if (Object.isUndefined(self._iteration)) {
			return;
		}
		setTimeout(function() { self._options.start(self._duration); }, 0);
		self._iterate();
	},
	_iterate: function() {
		var self = this;
		if (Object.isUndefined(self._iteration)) { return; }
		if (self._duration <= 0) {
			self._finish();
			return;
		}
		
		var currentTime = new Date();
		var time = currentTime.getTime();
		if ( time < self._currentTime || currentTime.getTimezoneOffset() != self._timezone ) {
			self._onError('Произошла смена часового пояса или изменение времени');
			return;
		}
		self._duration -= time - self._currentTime;
		self._currentTime = time;
		self._iteration++;
		self._callback();
		var timeout = (self._options.precision < self._duration)
			? self._options.precision
			: (self._duration > 0) ? self._duration : 0;
		setTimeout(self._iterate.bind(self), timeout);
	},
	_onError: function(errorText) {
		var self = this;
		self._options.onError(self._duration, errorText || '');
	},
	_callback: function() {
		var self = this;
		setTimeout(function() { self._options.callback(self._duration > 0 ? self._duration : 0); }, 0);
	},
	_finish: function() {
		var self = this;
		self._options.finish();
		self._iteration = eAu.undefined;
	},
	isIdle: function() {
		var self = this;
		return Object.isUndefined(self._iteration);
	},
	interrupt: function() {
		var self = this;
		if (!self.isIdle()) {
			self._options.interrupt(self._duration);
			self._iteration = eAu.undefined;
		}
		var timespan = (new Date()).getTime() - self._startTime;
		return (timespan <= self._options.duration) ? timespan : self._options.duration;
	}
});

})();
