<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="html" encoding="UTF-8" />

	<xsl:param name="element-title"/>
	<xsl:param name="parent-id"/>
	<xsl:param name="transformed-element-id"/>

	<!-- Удаляет фигурные скобки вначале и вконце строки -->
	<xsl:template name="stripBraces">
		<xsl:param name="string"/>
		<xsl:choose>
			<xsl:when test="substring($string,1,1)='{' and substring($string,string-length($string))='}'">
				<xsl:value-of select="translate(substring($string,2,string-length($string)-2), '-', '_')"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$string"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- Генерирует более приемлемый id на основе DB_ID -->
	<xsl:template name="genID">
		<xsl:param name="type">ID</xsl:param>
		<xsl:param name="id" />
		<xsl:value-of select="$type" />_<xsl:call-template name="stripBraces">
			<xsl:with-param name="string" select="$id" />
		</xsl:call-template><xsl:text>_EU</xsl:text>
	</xsl:template>

	<!-- Нормализация значения атрибута @width у тега <object> -->
	<xsl:template name="getWidth">
		<xsl:param name="node"/>
		<xsl:choose>
			<xsl:when test="$node/@width and $node/@width != '0' and $node/@width != ''">
				<xsl:value-of select="$node/@width"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="$node/@type = 'image'">
						<xsl:text>-1</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>800</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- Нормализация значения атрибута @height у тега <object> -->
	<xsl:template name="getHeight">
		<xsl:param name="node"/>
		<xsl:choose>
			<xsl:when test="$node/@height and $node/@height != '0' and $node/@height != ''">
				<xsl:value-of select="$node/@height"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="$node/@type = 'image'">
						<xsl:text>-1</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>600</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="getAlign">
		<xsl:param name="node"/>
		<xsl:choose>
			<xsl:when test="$node/@align = 'center' or $node/@align = 'left' or $node/@align = 'right'">
				<xsl:value-of select="$node/@align"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>left</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- Универсальный шаблон для отображения объектов -->
	<xsl:template match="object">
		<xsl:param name="type"/>
		<xsl:if test="
				    not(@visibility = 'hidden')
				and (not(@visible = 'false') or not(@default = 'false'))
			">
			<div class="eAu-object">
				<xsl:if test="$element-title and not(@visibility = 'hidden')">
					<h1 class="eAu"><xsl:value-of select="$element-title"/></h1>
				</xsl:if>
				<xsl:if test="not(@visible = 'false')">
					<div class="eAu-object-link">
						<img alt="{@type}" vspace="2" hspace="2" align="absmiddle" border="0" src="images/media/{@type}.gif"/>
						<a href="index.htm" onclick="return processInnerLinks(this, '{@DB_ID}');" target="_top"><xsl:value-of select="@title" /></a>
					</div>
				</xsl:if>
				<xsl:if test="@default = 'true'">
					<div class="eAu-object-embed">
						<xsl:variable name="width"><xsl:call-template name="getWidth"><xsl:with-param name="node" select="."/></xsl:call-template></xsl:variable>
						<xsl:variable name="height"><xsl:call-template name="getHeight"><xsl:with-param name="node" select="."/></xsl:call-template></xsl:variable>
						<xsl:variable name="align"><xsl:call-template name="getAlign"><xsl:with-param name="node" select="."/></xsl:call-template></xsl:variable>
						<xsl:variable name="id"><xsl:call-template name="genID"><xsl:with-param name="id" select="@DB_ID" /></xsl:call-template></xsl:variable>
						<xsl:choose>
							<xsl:when test="@type = 'image'">
								<img alt="{@title}" title="{@title}" src="{@src}" align="{$align}">
									<xsl:if test="$width != -1">
										<xsl:attribute name="width"><xsl:value-of select="$width"/></xsl:attribute>
									</xsl:if>
									<xsl:if test="$height != -1">
										<xsl:attribute name="height"><xsl:value-of select="$height"/></xsl:attribute>
									</xsl:if>
								</img>
								<br clear="all" />
							</xsl:when>
							<xsl:otherwise>
								<div class="eAu-object-alignment-container eAu-object-alignment-{$align}">
									<div style="width: {$width}px; height: {$height}px;" class="eAu-object-alignment">
										<xsl:choose>
											<xsl:when test="@type = 'silverlight'">
												<div style="background: white;"><div><div id="{$id}" /></div></div>
												<img src="images/loaded.gif">
													<xsl:attribute name="onload">
														attachDOM3EventOnNodeInserted.call(this);
														if (!inDOM.call(this)) { return; }
														
														$('#<xsl:value-of select="$id"/>')
															.parent()
															.html('<![CDATA[<object id=\']]><xsl:value-of select="$id"/><![CDATA[\' width=\']]><xsl:value-of select="$width"/><![CDATA[\' height=\']]><xsl:value-of select="$height"/><![CDATA[\' type=\'application/x-silverlight-2\' data=\'data:application/x-silverlight,\'><param name=\'source\' value=\']]><xsl:value-of select="@src"/><![CDATA[\'/><param name=\'background\' value=\'white\'/><param name=\'minRuntimeVersion\' value=\'2.0.31005.0\'/><param name=\'autoUpgrade\' value=\'true\'/></object>]]>');

														var me = this;
														setTimeout(function() {
															me.parentNode.removeChild(me);
														}, 0);
													</xsl:attribute>
												</img>
											</xsl:when>
											<xsl:when test="@type = 'flash'">
												<div style="background: white;"><div id="{$id}" /></div>
												<img src="images/loaded.gif">
													<xsl:attribute name="onload">
														attachDOM3EventOnNodeInserted.call(this);
														if (!inDOM.call(this)) { return; }

														embedFlashMovie(
															'<xsl:value-of select="@DB_ID" />',
															{
																<xsl:if test="$type = 'test'">
																	flashvars: {
																		fonload: 'question_exercise_set_flash_loaded(\'<xsl:value-of select="@DB_ID"/>\')'
																	},
																	params: {
																		allowScriptAccess: 'always',
																		scale: 'noScale'
																	},
																</xsl:if>
																width:  '<xsl:value-of select="$width" />',
																height: '<xsl:value-of select="$height" />'
															}
														);

														var me = this;
														setTimeout(function() {
															me.parentNode.removeChild(me);
														}, 0);
													</xsl:attribute>
												</img>
											</xsl:when>
											<xsl:otherwise>
												<iframe frameborder="0" marginheight="0" marginwidth="0" src="javascript:void(0);" style="display: none;" width="100%" height="100%" id="{$id}"/>
												<img src="images/loaded.gif">
													<xsl:attribute name="onload">
														attachDOM3EventOnNodeInserted.call(this);
														if (!inDOM.call(this)) { return; }
														<xsl:choose>
															<xsl:when test="@eAu-supported-extension and @eAu-supported-extension = 'false'">
																$('#<xsl:value-of select="$id"/>')
																	.attr('src', 'not-supported-extension.htm?extension=<xsl:value-of select="@eAu-filename-extension"/>&amp;filename=' + encodeURIComponent('<xsl:value-of select="@xslt-src"/>') )
																	.show();
															</xsl:when>
															<xsl:otherwise>
																$('#<xsl:value-of select="$id"/>')
																	.attr('src', encodeURI('<xsl:value-of select="@xslt-src"/>'))
																	.show();
															</xsl:otherwise>
														</xsl:choose>
														var me = this;
														setTimeout(function() {
															me.parentNode.removeChild(me);
														}, 0);
													</xsl:attribute>
												</img>
											</xsl:otherwise>
										</xsl:choose>
									</div>
								</div>
							</xsl:otherwise>
						</xsl:choose>
					</div>
				</xsl:if>
			</div>
		</xsl:if>
	</xsl:template>

	<!-- Универсальный шаблон для отображения текстовой ноды -->
	<xsl:template match="text">
		<xsl:if test="not(@visibility) = 'hidden'">
			<div class="eAu-paragraph-container">
				<xsl:if test="$element-title">
					<h1 class="eAu">
						<xsl:value-of select="$element-title"/>
						<xsl:if test="$parent-id"><a href="index.htm" onclick="link_info('{$parent-id}'); return false;" target="_top" title="Вернуться к основному содержимому"><img border="0" src="images/return.gif" width="18" height="18" align="absmiddle" hspace="7" /></a></xsl:if>
					</h1>
				</xsl:if>
				<div class="eAu-paragraph"><xsl:value-of select="."/></div>
			</div>
		</xsl:if>
	</xsl:template>

	<!-- Корневой элемент -->
	<xsl:template match="organization">
		<div class="eAu-organization-container">
			<div class="eAu-organization">
				<xsl:choose>
					<xsl:when test="intro"><xsl:apply-templates select="intro[position() = 1 and not(@visibility = 'hidden')]" /></xsl:when>
					<xsl:otherwise>
						<div class="eAu-intro-container">
							<div class="eAu-intro">
								Для начала работы выберите из содержания текущего курса соответствующий раздел
							</div>
						</div>
					</xsl:otherwise>
				</xsl:choose>
			</div>
		</div>
	</xsl:template>

	<!-- Вводный экран -->
	<xsl:template match="intro">
		<div class="eAu-intro-container">
			<h1 class="eAu"><xsl:value-of select="@title" /></h1>
			<div class="eAu-intro">
				<xsl:choose>
					<xsl:when test="object">
						<xsl:apply-templates select="object[not(@visibility = 'hidden')]"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates select="text[not(@visibility = 'hidden')]"/>
					</xsl:otherwise>
				</xsl:choose>
			</div>
		</div>
	</xsl:template>

	<!-- отображает раздел -->
	<xsl:template match="unit">
		<div class="eAu-item-container eAu-unit-container">
			<xsl:choose>
				<xsl:when test="$transformed-element-id = @DB_ID">
					<h1 class="eAu">
						<xsl:value-of select="@title"/>
						<xsl:if test="$parent-id"><a href="index.htm" onclick="link_info('{$parent-id}'); return false;" target="_top" title="Вернуться к основному содержимому"><img border="0" src="images/return.gif" width="18" height="18" align="absmiddle" hspace="7" /></a></xsl:if>
					</h1>
				</xsl:when>
				<xsl:otherwise>
					<h2 class="eAu"><a href="index.htm" onclick="link_info('{@DB_ID}'); return false;" target="_top"><xsl:value-of select="@title" /></a></h2>
				</xsl:otherwise>
			</xsl:choose>
			<div class="eAu-item eAu-unit">
				<xsl:apply-templates select="references[not(@visibility = 'hidden')] | subject[not(@visibility = 'hidden')] | unit[not(@visibility = 'hidden')] | lesson[not(@visibility = 'hidden')] | test[not(@visibility = 'hidden')] | studiedproblems[not(@visibility = 'hidden')] | studiedproblem[not(@visibility = 'hidden')]">
					<xsl:with-param name="mode">unit</xsl:with-param>
				</xsl:apply-templates>
			</div>
		</div>
	</xsl:template>

	<!-- отображает модуль (вид зависит от режима) -->
	<xsl:template match="lesson">
		<xsl:param name="mode" />
		<xsl:choose>
			<xsl:when test="$mode = 'unit'">
				<div class="eAu-item-container eAu-lesson-container">
					<h2 class="eAu">
						<table cellpadding="0" cellspacing="0" width="100%"><tr>
							<td style="padding-right: 5px;"><a href="index.htm" onclick="link_info('{@DB_ID}'); return false;" target="_top"><xsl:value-of select="@title" /></a></td>
							<td width="1">
								<a href="index.htm" onclick="toggleDescription('EAU-EXPANDABLE-{@DB_ID}', this); return false;" target="_top" title="Развернуть описание" class="button button-expand"><span></span></a>
							</td>
						</tr></table>
					</h2>
					<div class="eAu-item eAu-lesson" style="display: none;" id="EAU-EXPANDABLE-{@DB_ID}">
						<xsl:apply-templates select="subject[not(@visibility = 'hidden')] | references[not(@visibility = 'hidden')]" />
						<xsl:apply-templates select="test[not(@visibility = 'hidden')] | studiedproblems[not(@visibility = 'hidden')] | studiedproblem[not(@visibility = 'hidden')]">
							<xsl:with-param name="mode">unit</xsl:with-param>
						</xsl:apply-templates>
					</div>
				</div>
			</xsl:when>
			<xsl:when test="$mode = 'appendix' or ancestor::appendix-item">
				<div class="eAu-appendix-lesson">
					<xsl:call-template name="modules">
						<xsl:with-param name="node" select="." />
					</xsl:call-template>
				</div>
			</xsl:when>
			<xsl:otherwise>
				<div class="eAu-lesson-container">
					<h1 class="eAu">
						<xsl:value-of select="@title"/>
						<xsl:if test="$parent-id"><a href="index.htm" onclick="link_info('{$parent-id}'); return false;" target="_top" title="Вернуться к основному содержимому"><img border="0" src="images/return.gif" width="18" height="18" align="absmiddle" hspace="7" /></a></xsl:if>
					</h1>
					<div class="eAu-lesson">
						<xsl:apply-templates select="subject[not(@visibility = 'hidden')] | references[not(@visibility = 'hidden')]" />
						<xsl:apply-templates select="test[not(@visibility = 'hidden')] | studiedproblems[not(@visibility = 'hidden')] | studiedproblem[not(@visibility = 'hidden')]">
							<xsl:with-param name="mode">lesson</xsl:with-param>
						</xsl:apply-templates>
					</div>
				</div>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- Тема модуля/раздела -->
	<xsl:template match="subject">
		<div class="eAu-subject-container">
			<h2 class="eAu"><xsl:value-of select="@title" /></h2>
			<div class="eAu-subject"><xsl:value-of select="." /></div>
		</div>
	</xsl:template>

	<!-- Список литературы -->
	<xsl:template match="references">
		<div class="eAu-references-container">
			<h2 class="eAu"><xsl:value-of select="@title" /></h2>
			<ol class="eAu-references">
				<xsl:apply-templates select="reference[not(@visibility = 'hidden')] | object[not(@visibility = 'hidden')]"/>
			</ol>
		</div>
	</xsl:template>
	<xsl:template match="reference">
		<li class="eAu-make-inline eAu-reference"><xsl:value-of select="." /></li>
	</xsl:template>

	<!-- Ссылка на тест в unit-view и lesson-view -->
	<xsl:template match="test">
		<xsl:param name="mode" />
		<xsl:choose>
			<xsl:when test="$mode = 'unit' or $mode = 'lesson'">
				<div class="eAu-test-link"><a href="index.htm" onclick="link_info('{@DB_ID}'); return false;" target="_top"><xsl:value-of select="@title" /></a></div>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<!-- Список тем -->
	<xsl:template match="studiedproblems">
		<xsl:param name="mode" />
		<xsl:choose>
			<xsl:when test="$mode = 'unit' or $mode = 'lesson'">
				<xsl:if test="count(studiedproblem[not(@visibility = 'hidden')]) > 0">
					<fieldset class="eAu-studiedproblems-container">
						<xsl:if test="@title and @title != ''">
							<legend class="eAu"><xsl:value-of select="@title" /></legend>
						</xsl:if>
						<div class="eAu-studiedproblems">
							<xsl:apply-templates select="studiedproblem[not(@visibility = 'hidden')]">
								<xsl:with-param name="mode" select="$mode" />
							</xsl:apply-templates>
						</div>
					</fieldset>
				</xsl:if>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<!-- Отображает тему в режиме обучения -->
	<!-- если показывается в unit-view или lesson-view, -->
	<!-- то отображается только ссылка -->
	<xsl:template match="studiedproblem">
		<xsl:param name="mode" />
		<xsl:choose>
			<xsl:when test="$mode = 'unit' or $mode = 'lesson'">
				<div class="eAu-studiedproblem-link"><a href="index.htm" onclick="link_info('{@DB_ID}'); return false;" target="_top" class="some-cool-clasZ"><xsl:value-of select="@title"/></a></div>
			</xsl:when>
			<xsl:when test="$mode = 'appendix' or ancestor::appendix-item">
				<xsl:call-template name="studiedproblem"><xsl:with-param name="node" select="."/></xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<div class="eAu-studiedproblem-container">
					<h1 class="eAu">
						<xsl:value-of select="@title" />
						<xsl:if test="$parent-id"><a href="index.htm" onclick="link_info('{$parent-id}'); return false;" target="_top" title="Вернуться к основному содержимому"><img border="0" src="images/return.gif" width="18" height="18" align="absmiddle" hspace="7" /></a></xsl:if>
					</h1>
					<div class="eAu-studiedproblem"><xsl:apply-templates select="text[not(@visibility = 'hidden')] | object[not(@visibility = 'hidden')]" /></div>
				</div>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- Отображает тему в приложении -->
	<xsl:template name="studiedproblem">
		<xsl:param name="heading" select="'h1'"/>
		<xsl:param name="node"/>
		<div class="eAu-studiedproblem-container">
			<xsl:element name="{$heading}">
				<xsl:attribute name="class">eAu</xsl:attribute>
				<xsl:value-of select="$node/@title" />
			</xsl:element>
			<div class="eAu-studiedproblem"><xsl:apply-templates select="$node/*[not(@visibility = 'hidden')]" /></div>
		</div>
	</xsl:template>

	<!-- Отображает список тем внутри модуля -->
	<xsl:template name="modules">
		<xsl:param name="node" />
		<div class="eAu-modules-container">
			<h1 class="eAu"><xsl:value-of select="$node/@title" /></h1>
			<div class="eAu-modules">
				<xsl:for-each select="$node/*">
					<xsl:if test="name(.) = 'lesson'">
						<div class="eAu-appendix-lesson">
							<xsl:call-template name="modules">
								<xsl:with-param name="node" select="." />
							</xsl:call-template>
						</div>
					</xsl:if>
					<xsl:if test="name(.) = 'studiedproblem'">
						<xsl:call-template name="studiedproblem">
							<xsl:with-param name="node" select="."/>
							<xsl:with-param name="heading" select="'h2'"/>
						</xsl:call-template>
						<xsl:if test="position() != count(../*)">
							<div class="eAu-content-dotted-line"></div>
						</xsl:if>
					</xsl:if>
				</xsl:for-each>
			</div>
		</div>
	</xsl:template>

	<!-- Корневой элемент приложения -->
	<xsl:template match="appendix-item">
		<xsl:choose>
			<xsl:when test="intro"><xsl:apply-templates select="intro[position() = 1 and not(@visibility = 'hidden')]" /></xsl:when>
			<xsl:otherwise>
				<div class="eAu-intro-container">
					<h1 class="eAu"><xsl:value-of select="@title"/></h1>					
					<div class="eAu-intro">
						Для продолжения работы выберите из содержания текущего приложения соответствующий раздел
					</div>
				</div>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- Вопросы для контроля -->
	<xsl:template match="question | question-exercise">
		<div class="eAu-question-container">	
			<h1 class="eAu">
				<xsl:value-of select="../@title"/>
			</h1>
			<div id="eAu-test-statistics" class="eAu-test-statistics">
				<table cellpadding="0" cellspacing="0" style="border-collapse: collapse;" border="0" width="100%">
					<tr><td>
						<div id="eAu-test-questions-statistics"></div>
						<div id="eAu-test-time" class="eAu-test-time"></div>
					</td>
					<td align="right">
						<div id="eAu-test-break">
							<a href="index.htm" onclick="break_test(); return false;" target="_top">прервать тестирование</a>
						</div>
						<div style="display: none;" id="eAu-test-end">
							<a href="index.htm" onclick="end_test(); return false;" target="_top" id="eAu-test-end">досрочно завершить тестирование</a>
						</div>
					</td></tr>
				</table>
			</div>
			<h2 class="eAu" id="eAu-question-title-{@DB_ID}"><xsl:value-of select="@title"/></h2>
			<div id="eAu-question-statistics" class="eAu-test-statistics">
				<xsl:if test="local-name(..) = 'question-group' and ../@name and normalize-space(../@name) != ''">
					<div class="eAu-question-theme">тема вопроса <![CDATA[&ndash;]]> <span><xsl:value-of select="normalize-space(../@name)" /></span></div>
				</xsl:if>
				<div id="eAu-question-time" class="eAu-quesion-time"></div>
			</div>
			<xsl:if test="text and normalize-space(text) != '' and normalize-space(text) != ' '">
				<div class="eAu-question-text"><xsl:value-of select="text"/></div>
			</xsl:if>
			<div class="eAu-question-answers eAu-question-answers-interactive" id="eAu-question-answers">
				<xsl:apply-templates select="answers | object">
					<xsl:with-param name="type">test</xsl:with-param>
				</xsl:apply-templates>
			</div>
		</div>
	</xsl:template>

	<xsl:template match="question/answers">
		<form action="" id="eAu-question-form" name="eAu-question-form" onsubmit="return false;" class="eAu-question-type-{../@type}">
			<table cellpadding="0" cellspacing="0" style="border-collapse: collapse;">
				<xsl:apply-templates select="answer"/>
			</table>
		</form>
	</xsl:template>

	<xsl:template match="question[@type='single']/answers/answer">
		<xsl:variable name="DB_ID"><xsl:value-of select="../../@DB_ID"/></xsl:variable>
		<tr>
			<td><input type="radio" name="EU-{$DB_ID}" id="EU-{$DB_ID}-{@DB_ID}" value="{@DB_ID}" class="eAu-input-radio" /></td>
			<td class="eAu-answer-variant">
				<xsl:attribute name="onclick">
					var node = document.getElementById('EU-<xsl:value-of select="$DB_ID"/>-<xsl:value-of select="@DB_ID"/>');
					if (!node.disabled) {
						node.checked = true;
					}
				</xsl:attribute>
				<div>
					<xsl:choose>
						<xsl:when test="normalize-space(.) = ''">
							<i style="text-decoration: line-through;">тект ответа отсутствует</i>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="."/>
						</xsl:otherwise>
					</xsl:choose>
				</div>
			</td>
			<td class="eAu-answer-indicator"></td>
		</tr>
	</xsl:template>

	<xsl:template match="question[@type='multiple']/answers/answer">
		<xsl:variable name="DB_ID"><xsl:value-of select="../../@DB_ID"/></xsl:variable>
		<tr>
			<td><input type="checkbox" name="EU-{$DB_ID}-{@DB_ID}" id="EU-{$DB_ID}-{@DB_ID}-1" value="1" class="eAu-input-checkbox"/></td>
			<td class="eAu-answer-variant">
				<xsl:attribute name="onclick">
					var node = document.getElementById('EU-<xsl:value-of select="$DB_ID"/>-<xsl:value-of select="@DB_ID"/>-1');
					if (!node.disabled) {
						node.checked = node.checked ? false : true;
					}
				</xsl:attribute>
				<div>
					<xsl:choose>
						<xsl:when test="normalize-space(.) = ''">
							<i style="text-decoration: line-through;">тект ответа отсутствует</i>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="."/>
						</xsl:otherwise>
					</xsl:choose>
				</div>
			</td>
			<td class="eAu-answer-indicator"></td>
		</tr>
	</xsl:template>

	<xsl:template match="question[@type='fill']/answers/answer">
		<tr>
			<td class="eAu-answer-variant"><xsl:if test="not(normalize-space(.) = '')"><div><xsl:value-of select="."/></div></xsl:if></td>
			<td><xsl:if test="not(normalize-space(.) = '')"><span class="eAu-arrow">→</span></xsl:if></td>
			<td><input type="text" class="eAu-input-text" width="40" id="EU-{@DB_ID}" name="EU-{@DB_ID}" /></td>
			<td class="eAu-answer-indicator"></td>
			<td id="EU-RA-{@DB_ID}"></td>
		</tr>
	</xsl:template>

	<xsl:template match="question[@type='compare']/answers/answer">
		<tr>
			<td class="eAu-answer-variant">
				<xsl:choose>
					<xsl:when test="normalize-space(.) = ''">
						<i style="text-decoration: line-through;">тект ответа отсутствует</i>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</td>
			<td><span class="eAu-arrow">→</span></td>
			<td>
				<select id="EU-{@DB_ID}" name="EU-{@DB_ID}" class="eAu-input-text">
					<xsl:for-each select="../answer">
						<xsl:sort select="@right"/>
						<option val="{@right}" value="EU-VAL-{@DB_ID}"><xsl:value-of select="@right"/></option>
					</xsl:for-each>
				</select>
			</td>
			<td class="eAu-answer-indicator"></td>
			<td id="EU-RA-{@DB_ID}"></td>
		</tr>
	</xsl:template>	

	<xsl:template match="question[@type='sort']/answers" priority="10">
		<div id="eAu-question-sortables-area" class="eAu-question-sortables-area eAu-question-sort">
			<div class="eAu-sortable-container">
				<div id="eAu-sortable-0" class="eAu-sortable">
					<xsl:for-each select="answer">
						<div class="eAu-sortable-item" id="EU-{@DB_ID}">
							<div class="eAu-sortable-item-container">
								<table cellpadding="0" cellspacing="0" border="0" width="100%"><tr>
									<td class="eAu-answer-variant">
										<xsl:choose>
											<xsl:when test="normalize-space(.) = ''">
												<i style="text-decoration: line-through;">тект ответа отсутствует</i>
											</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="."/>
											</xsl:otherwise>
										</xsl:choose>
									</td>
									<td class="eAu-answer-indicator"></td>
									<td class="eAu-answer-right" id="EU-RA-{@DB_ID}"></td>
								</tr></table>
							</div>
						</div>
					</xsl:for-each>
				</div>
			</div>
			<img src="images/loaded.gif">
				<xsl:attribute name="onload">
					attachDOM3EventOnNodeInserted.call(this);
					if (!inDOM.call(this)) { return; }
					restoreSortableOrder();
					$('.eAu-sortable').sortable({
						axis: 'y',
						grid: [1, 1],
						opacity: 0.7,
						delay: 5,
						connectWith: ['.eAu-sortable'],
						dropOnEmpty: true,
						stop: function(event, ui) {
							ui.item[0].style.opacity = '';
							ui.item[0].style.filter = '';
						}
					});
					var me = this;
					setTimeout(function() {
						me.parentNode.removeChild(me);
					}, 0);
				</xsl:attribute>
			</img>
		</div>
	</xsl:template>

	<xsl:template name="classify-group-title">
		<xsl:param name="value"/>
		<h3 class="eAu">
			<xsl:choose>
				<xsl:when test="$value = ''">
					<i>Категория без имени</i>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$value"/>
				</xsl:otherwise>
			</xsl:choose>
		</h3>
	</xsl:template>
	
	<xsl:template match="question[@type='classify']/answers" priority="10">
		<div id="eAu-question-sortables-area" class="eAu-question-sortables-area eAu-question-classify">
			<xsl:for-each select="../classes/class/@name">
				<xsl:sort select="string(.)"/>
				<xsl:call-template name="classify-group-title">
					<xsl:with-param name="value" select="../@display-name"/>
				</xsl:call-template>
				<div class="eAu-sortable-container">
					<div id="eAu-sortable-{position()}" class="eAu-sortable" group="{.}">
					</div>
				</div>
			</xsl:for-each>
			<div class="eAu-sortable-container">
				<div id="eAu-sortable-0" class="eAu-sortable">
					<xsl:for-each select="answer">
						<div class="eAu-sortable-item" id="EU-{@DB_ID}">
							<div class="eAu-sortable-item-container">
								<table cellpadding="0" cellspacing="0" border="0" width="100%"><tr>
									<td class="eAu-answer-variant">
										<xsl:choose>
											<xsl:when test="normalize-space(.) = ''">
												<i style="text-decoration: line-through;">тект ответа отсутствует</i>
											</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="."/>
											</xsl:otherwise>
										</xsl:choose>
									</td>
									<td width="1" class="eAu-answer-right" id="EU-RA-{@DB_ID}"></td>
									<td class="eAu-answer-indicator"></td>
								</tr></table>
							</div>
						</div>
					</xsl:for-each>
				</div>
			</div>
			<img src="images/loaded.gif">
				<xsl:attribute name="onload">
					attachDOM3EventOnNodeInserted.call(this);
					if (!inDOM.call(this)) { return; }
					restoreClassifyOrder();
					$('.eAu-sortable').sortable({
						axis: 'y',
						opacity: 0.7,
						delay: 5,
						grid: [1, 1],
						connectWith: ['.eAu-sortable'],
						dropOnEmpty: true,
						stop: function(event, ui) {
							ui.item[0].style.opacity = '';
							ui.item[0].style.filter = '';
						}
					});
					var me = this;
					setTimeout(function() {
						me.parentNode.removeChild(me);
					}, 0);
				</xsl:attribute>
			</img>
		</div>
	</xsl:template>
</xsl:stylesheet>
